import $ from 'jquery'
import { Plugin } from 'foundation-sites/js/foundation.core.plugin'
import A11YSlider from '@moreonion/a11y-slider'

/**
 * Slideshow module
 *
 * A11ySlider allows to build sliders and carousels.
 * Refer to https://a11yslider.js.org/ for further documentation.
 * Plugin options can be set as data attributes to the wrapper of items that
 * should be displayed within a slideshow.
 *
 * @module foundation.slideshow
 */

class Slideshow extends Plugin {
  /**
   * Creates a new instance.
   * @class
   * @name Slideshow
   * @fires Slideshow#init
   * @param {Object} element - jQuery object representing the Slideshow wrapper.
   * @param {Object} options - Overrides to the default plugin settings.
   */
  _setup (element, options = {}) {
    this.$element = element
    this.className = 'Slideshow'
    this.options = $.extend(true, {}, Slideshow.defaults, this.$element.data(), options)
    this._log('setup', this)
    this._init()
  }

  /**
   * Initializes the plugin and calls functions to get functioning on load.
   * @private
   */
  _init () {
    this.slideshow = new A11YSlider(this.$element[0], {
      dots: this.options.dots,
      arrows: this.options.arrows,
      autoplay: this.options.autoplay,
      autoplaySpeed: this.options.autoplaySpeed,
      infinite: this.options.infinite,
      swipe: this.options.swipe
    })
    this._log('init', this)
  }

  /**
   * Destroys an instance.
   * @function
   */
  _destroy () {
    this.slideshow.destroy()
    this._log('destroyed', this)
  }

  /**
   * Logs debug output to the console.
   * @function
   * @private
   */
  _log () {
    if (this.options.debug) {
      console.debug('[Slideshow]', ...arguments)
    }
  }
}

/**
 * Default settings for plugin
 */
Slideshow.defaults = {

  /**
   * Toggle autoplay of slideshow.
   *
   * @option
   * @type {boolean}
   * @default false
   */
  autoplay: false,

  /**
   * Time between slide changes when autoplay is enabled (milliseconds).
   *
   * @option
   * @type {number}
   * @default 4000
   */
  autoplaySpeed: 4000,

  /**
   * Generate navigation dots.
   * @option
   * @type {boolean}
   * @default false
   */
  dots: false,

  /**
   * Enables prev/next button
   * @option
   * @type {boolean}
   * @default false
   */
  arrows: false,

  /**
  * Toggle infinite loop.
  * @option
  * @type {boolean}
  * @default false
  */
  infinite: false,

  /**
  * Toggle JS swiping.
  * @option
  * @type {boolean}
  * @default false
  */
  swipe: false,

  /**
   * Toggle debug output.
   * @option
   * @type {boolean}
   * @default false
   */
  debug: false,
}

export { Slideshow }
